@@ -1,11 +1,12 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008-2009 Michael Howitz
+# Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: edit.py 702 2009-11-22 15:24:09Z icemac $
+# $Id: edit.py 803 2010-01-23 20:29:02Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import gocept.reference.interfaces
 import icemac.addressbook.browser.base
+import icemac.addressbook.browser.metadata
 import icemac.addressbook.interfaces
 import z3c.form.button
 import zope.interface
@@ -14,13 +15,15 @@ import zope.security.proxy
 import zope.size.interfaces
 
 
-class EditForm(icemac.addressbook.browser.base.BaseEditForm):
+class EditForm(icemac.addressbook.browser.base.GroupEditForm):
 
     label = _(u'Edit address book data')
     interface = icemac.addressbook.interfaces.IAddressBook
+    groups = (icemac.addressbook.browser.metadata.MetadataGroup,)
     next_url = 'object'
     next_view = '@@edit.html'
 
+
     @z3c.form.button.buttonAndHandler(_('Apply'), name='apply')
     def handleApply(self, action):
         super(EditForm, self).handleApply(self, action)
