@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: interfaces.py 862 2010-03-06 20:15:14Z icemac $
+# $Id: interfaces.py 1020 2010-08-17 19:16:54Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import gocept.country
@@ -114,7 +114,7 @@ class IKeywords(zope.interface.Interface):
     """Collection of keywords."""
 
     def get_keywords():
-        """Get the keywords in the collection."""
+        """Get an iterable of the keywords in the collection."""
 
     def get_keyword_by_title(title, default=None):
         "Get the keyword with the given title or `default`."
@@ -151,9 +151,19 @@ class IEntity(zope.interface.Interface):
 
     name = zope.interface.Attribute(
         "Uniqe name of the entity which only contains letters.")
+    tagged_values = zope.interface.Attribute(
+        "Dict of tagged values of the entity.")
+
+    def getRawField(field_name):
+        """Get a field by its name. (Without any conversion.)"""
 
     def getField(field_name):
-        """Get a zope.schema field by its name."""
+        """Get a zope.schema field by its name.
+
+        When the field is a user defined one it gets converted to a zope.schema
+        field.
+        """
+
 
     def getRawFields():
         """Get ordered name, field tuples of the schema fields on the entity.
