@@ -1,12 +1,15 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: addressbook.py 783 2010-01-09 14:28:06Z icemac $
+# $Id: addressbook.py 1022 2010-08-17 19:19:23Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import icemac.addressbook.entities
+import icemac.addressbook.file.interfaces
 import icemac.addressbook.interfaces
 import icemac.addressbook.keyword
+import icemac.addressbook.orderstorage
+import icemac.addressbook.preferences.default
 import icemac.addressbook.utils
 import zc.catalog.catalogindex
 import zope.app.appsetup.bootstrap
@@ -24,6 +27,7 @@ import zope.intid
 import zope.intid.interfaces
 import zope.location
 import zope.location.interfaces
+import zope.preference.interfaces
 import zope.schema.fieldproperty
 import zope.site.site
 
@@ -38,10 +42,13 @@ class AddressBook(zope.container.btree.BTreeContainer,
     importer = None
     keywords = None
     principals = None
+    orders = None
 
     title = zope.schema.fieldproperty.FieldProperty(
         icemac.addressbook.interfaces.IAddressBook['title'])
 
+    def __repr__(self):
+        return "<AddressBook %r (%r)>" % (self.__name__, self.title)
 
 address_book_entity = icemac.addressbook.entities.create_entity(
     _(u'address book'), icemac.addressbook.interfaces.IAddressBook, AddressBook)
@@ -87,41 +94,41 @@ def create_address_book_infrastructure(addressbook, event=None):
         icemac.addressbook.entities.PersistentEntities,
         icemac.addressbook.interfaces.IEntities)
 
+    # add order storage utility
+    create_and_register(
+        addressbook, 'orders',
+        icemac.addressbook.orderstorage.OrderStorage,
+        icemac.addressbook.interfaces.IOrderStorage)
+
+    def add_entity_to_order(iface):
+        addressbook.orders.add(
+            icemac.addressbook.interfaces.IEntity(iface).name,
+            icemac.addressbook.interfaces.ENTITIES)
+
+    add_entity_to_order(icemac.addressbook.interfaces.IAddressBook)
+    add_entity_to_order(icemac.addressbook.interfaces.IPostalAddress)
+    add_entity_to_order(icemac.addressbook.interfaces.IPhoneNumber)
+    add_entity_to_order(icemac.addressbook.interfaces.IEMailAddress)
+    add_entity_to_order(icemac.addressbook.interfaces.IHomePageAddress)
+    add_entity_to_order(icemac.addressbook.file.interfaces.IFile)
+    add_entity_to_order(icemac.addressbook.interfaces.IPerson)
+    add_entity_to_order(icemac.addressbook.interfaces.IKeyword)
+
     add_more_addressbook_infrastructure(addressbook, addressbook)
 
 
-def utility_locally_registered(site, interface):
-    """Test, whether a utility is registered on the site manager of the site.
-
-    interface ... interface the utility is registered for
-
-    """
-
-    for registration in site.getSiteManager().registeredUtilities():
-        if registration.provided == interface:
-            return True
-    return False
-
-
 @icemac.addressbook.utils.set_site
 def add_more_addressbook_infrastructure(addressbook):
     "Add more infrastructure which depends on addressbook set as site."
     # intid utility
-    if not utility_locally_registered(addressbook,
-                                      zope.intid.interfaces.IIntIds):
+    if not icemac.addressbook.utils.utility_locally_registered(
+            addressbook, zope.intid.interfaces.IIntIds):
         intids = zope.app.appsetup.bootstrap.ensureUtility(
             addressbook, zope.intid.interfaces.IIntIds, '', zope.intid.IntIds)
 
-        # register existing persons with intid utility
-        for person in addressbook.values():
-            intids.register(person)
-            # register adresses of persons
-            for value in person.values():
-                intids.register(value)
-
     # catalog
-    if utility_locally_registered(addressbook,
-                                  zope.catalog.interfaces.ICatalog):
+    if icemac.addressbook.utils.utility_locally_registered(
+            addressbook, zope.catalog.interfaces.ICatalog):
         catalog = zope.component.queryUtility(zope.catalog.interfaces.ICatalog)
     else:
         # add catalog
@@ -136,11 +143,14 @@ def add_more_addressbook_infrastructure(addressbook):
             field_callable=True)
 
     # authenticator (PAU)
-    if not utility_locally_registered(
-        addressbook, zope.authentication.interfaces.IAuthentication):
+    if not icemac.addressbook.utils.utility_locally_registered(
+            addressbook, zope.authentication.interfaces.IAuthentication):
         pau = zope.app.appsetup.bootstrap.ensureUtility(
             addressbook, zope.authentication.interfaces.IAuthentication, '',
             zope.app.authentication.authentication.PluggableAuthentication)
         pau.credentialsPlugins = (u'No Challenge if Authenticated',
                                   u'Session Credentials',)
         pau.authenticatorPlugins = (u'icemac.addressbook.principals',)
+
+    # default preferences
+    icemac.addressbook.preferences.default.add(addressbook)
