@@ -45,11 +45,6 @@ def all_(*constraints):
     return lambda form: all(constraint(form) for constraint in constraints)
 
 
-def get_entities_util():
-    """Return the user entities utility."""
-    return zope.component.getUtility(icemac.addressbook.interfaces.IEntities)
-
-
 class BaseView(object):
     "Base for view classes."
 
@@ -67,7 +62,7 @@ class BaseForm(BaseView):
 
     @property
     def fields(self):
-        fields = get_entities_util().getEntity(self.interface)
+        fields = icemac.addressbook.interfaces.IEntity(self.interface)
         return z3c.form.field.Fields(*fields.getFieldValuesInOrder())
 
 
@@ -121,6 +116,7 @@ class BaseEditForm(BaseForm, z3c.formui.form.EditForm):
 
     next_url = None # target object after edit, one of ('object', 'parent')
     next_view = None # target view after edit (None for default view)
+    id = 'edit-form'
 
     def render(self):
         if self.request.response.getStatus() in (302, 303, 304):
@@ -215,7 +211,7 @@ class PrefixGroup(z3c.form.group.Group):
 
     @property
     def fields(self):
-        fields = get_entities_util().getEntity(self.interface)
+        fields = icemac.addressbook.interfaces.IEntity(self.interface)
         return z3c.form.field.Fields(
             *fields.getFieldValuesInOrder(), **dict(prefix=self.prefix))
 
