@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: table.py 783 2010-01-09 14:28:06Z icemac $
+# $Id: table.py 1023 2010-08-17 19:20:20Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import icemac.addressbook.interfaces
 import icemac.truncatetext
+import z3c.table.batch
 import z3c.table.column
 import z3c.table.table
 
@@ -35,13 +36,33 @@ class DeleteLinkColumn(z3c.table.column.LinkColumn):
 
 
 class TruncatedContentColumn(z3c.table.column.GetAttrColumn):
+    "Column which truncates its content to `length` characters."
 
-    length = 20
-    attrName = None
+    length = 20 # number of characters to display
+    attrName = None # attribute to access
+    ellipsis = u'…' # ellipsis sign
+    defaultValue = u'' # default value when there is no value
 
     def getValue(self, obj):
         value = super(TruncatedContentColumn, self).getValue(obj)
-        return icemac.truncatetext.truncate(value, self.length)
+        if value is None:
+            return self.defaultValue
+        result = icemac.truncatetext.truncate(value, self.length, self.ellipsis)
+        return result
+
+
+class KeywordsColumn(z3c.table.column.GetAttrColumn):
+    """GetAttrColumn where attr is an iterable of keywords."""
+
+    def getSortKey(self, item):
+        return super(KeywordsColumn, self).getSortKey(item).lower()
+
+    def getValue(self, obj):
+        values = super(KeywordsColumn, self).getValue(obj)
+        return u', '.join(sorted(
+            (icemac.addressbook.interfaces.ITitle(x) for x in values),
+            key=lambda x: x.lower()))
+
 
 
 # Tables
@@ -49,6 +70,8 @@ class TruncatedContentColumn(z3c.table.column.GetAttrColumn):
 class Table(z3c.table.table.Table):
     "Table which supports a no-rows-found message."
 
+    cssClassEven = u'table-even-row'
+    cssClassOdd = u'table-odd-row'
     startBatchingAt = 1000000
     no_rows_message = u'' # Set at subclass.
 
@@ -68,3 +91,11 @@ class PageletTable(z3c.pagelet.browser.BrowserPagelet, Table):
         super(PageletTable, self).__init__(*args, **kw)
         Table.__init__(self, *args, **kw)
     update = Table.update
+
+
+# Batching
+
+class NiceBatchProvider(z3c.table.batch.BatchProvider):
+    """A batch provider with a nicer spacer."""
+
+    batchSpacer = u'…'
