@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008-2009 Michael Howitz
+# Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: utils.py 997 2009-02-03 16:58:46Z mac $
+# $Id: utils.py 1022 2010-08-17 19:19:23Z icemac $
 
 import zope.container.interfaces
 import zope.event
@@ -54,3 +54,15 @@ def iter_by_interface(container, interface):
         if interface.providedBy(obj):
             yield obj
 
+
+def utility_locally_registered(site, interface):
+    """Test, whether a utility is registered on the site manager of the `site`.
+
+    interface ... interface the utility is registered for
+
+    """
+
+    for registration in site.getSiteManager().registeredUtilities():
+        if registration.provided == interface:
+            return True
+    return False
